@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000  Roland Rosenfeld <roland@spinnaker.de>
+ *  Copyright (C) 2000-2005  Roland Rosenfeld <roland@spinnaker.de>
  *
  *  This program is free software; you can redistribute
  *  it and/or modify it under the terms of the GNU
@@ -13,14 +13,13 @@
  *  PARTICULAR PURPOSE.  See the GNU General Public
  *  License for more details.
  *
- *  You should have received a copy of the GNU General
- *  Public License along with this program; if not, write
- *  to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA  02111, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,, USA.
  *
  */
 
-/* $Id: qpto8bit.c,v 1.2 2000/08/05 19:24:03 roland Exp $ */
+/* $Id: qpto8bit.c,v 1.4 2007-10-28 16:33:36 roland Exp $ */
 
 #include <stdio.h>
 
@@ -28,9 +27,17 @@
 #include "rfc822.h"
 #include "rfc2047.h"
 
-int main ()
+int main (int argc, char * argv[])
 {
   char buff[2048];
+#ifdef HAVE_ICONV
+  const char **charsetptr = &Charset;
+#endif
+
+#ifdef HAVE_ICONV
+  if (argc > 1)
+    *charsetptr = argv[1];
+#endif
 
   while (fgets (buff, sizeof (buff), stdin)) {
     rfc2047_decode (buff, buff, sizeof (buff));
